@@ -112,8 +112,8 @@ class AppController():
         except ParseAppDeploymentName:
             raise InputErrorException('InvalidApplicationName')
 
-        if deployment_name == '':
-            raise InputErrorException('NoDeployment')
+        if not deployment_name:
+            deployment_name = 'default'
 
         user_host = '{app}-{dep}@{host}'.format(app=app_name, dep=deployment_name, host=self.settings.ssh_forwarder)
 
@@ -141,8 +141,8 @@ class AppController():
         except ParseAppDeploymentName:
             raise InputErrorException('InvalidApplicationName')
 
-        if deployment_name == '':
-            raise InputErrorException('NoDeployment')
+        if not deployment_name:
+            deployment_name = 'default'
 
         logEntries = []
 
@@ -406,6 +406,8 @@ class AppController():
             app_name, deployment_name = self.parse_app_deployment_name(args.name)
         except ParseAppDeploymentName:
             raise InputErrorException('InvalidApplicationName')
+        if not deployment_name:
+            deployment_name = 'default'
         if args.size:
             size = args.size
             if args.memory:
@@ -449,8 +451,15 @@ class AppController():
                     raise InputErrorException('InvalidSize')
             else:
                 raise
-        else:
-            return True
+
+        if args.restart_workers:
+            deployment = {'state': 'unknown'}
+            while deployment['state'] != 'deployed':
+                time.sleep(1)
+                deployment = self.api.read_deployment(app_name, deployment_name)
+            self._restartWorkers(app_name, deployment_name)
+
+        return True
 
     def redeploy(self, deployment):
         """
@@ -474,7 +483,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not self.does_app_exist(app_name):
             raise InputErrorException('WrongApplication')
         if not args.force_delete:
@@ -498,7 +507,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.alias:
             raise InputErrorException('NoAliasGiven')
         self.api.create_alias(app_name, args.alias, deployment_name)
@@ -510,7 +519,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.alias:
             aliases = self.api.read_aliases(app_name, deployment_name)
             print_alias_list(aliases)
@@ -533,7 +542,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.alias:
             raise InputErrorException('NoAliasGiven')
         try:
@@ -557,7 +566,7 @@ class AppController():
         else:
             size = None
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.command:
             raise InputErrorException('NoWorkerCommandGiven')
         try:
@@ -583,7 +592,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.wrk_id:
             workers = (self.api.read_worker(app_name, deployment_name, worker['wrk_id']) for worker in self.api.read_workers(app_name, deployment_name))
             print_worker_list(workers)
@@ -606,20 +615,51 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         try:
             self.api.delete_worker(app_name, deployment_name, args.wrk_id)
         except GoneError:
             raise InputErrorException('WrongWorker')
         return True
 
+    def _restartWorker(self, app_name, deployment_name, wrk_id, command, params, size):
+        self.api.delete_worker(app_name, deployment_name, wrk_id)
+        self.api.create_worker(
+            app_name,
+            deployment_name,
+            command,
+            params,
+            size)
+
+    def _restartWorkers(self, app_name, deployment_name):
+        workers = (self.api.read_worker(app_name, deployment_name, worker['wrk_id']) for worker in self.api.read_workers(app_name, deployment_name))
+        for worker in workers:
+            self._restartWorker(app_name, deployment_name, worker['wrk_id'], worker['command'], worker['params'], worker['size'])
+
+    def restartWorker(self, args):
+        app_name, deployment_name = self.parse_app_deployment_name(args.name)
+        if not deployment_name:
+            deployment_name = 'default'
+
+        if args.wrk_id:
+            try:
+                worker = self.api.read_worker(app_name, deployment_name, args.wrk_id)
+            except GoneError:
+                raise InputErrorException('WrongWorker')
+
+            self._restartWorker(app_name, deployment_name, worker['wrk_id'], worker['command'], worker['params'], worker['size'])
+            return
+
+        if args.all:
+            self._restartWorkers(app_name, deployment_name)
+
     def addCron(self, args):
         """
             Adds the given worker to the deployment.
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.url:
             raise InputErrorException('NoCronURLGiven')
         self.api.create_cronjob(
@@ -634,7 +674,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.job_id:
             cronjobs = self.api.read_cronjobs(app_name, deployment_name)
             print_cronjob_list(cronjobs)
@@ -657,7 +697,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         try:
             self.api.delete_cronjob(app_name, deployment_name, args.job_id)
         except GoneError:
@@ -677,7 +717,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
 
         config = self._get_config_vars(app_name, deployment_name)
 
@@ -694,7 +734,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.variables:
             raise InputErrorException('NoVariablesGiven')
 
@@ -715,7 +755,7 @@ class AppController():
         except ThrottledError as te:
             # Overwrite the variable if didn't force, but type Yes
             question = raw_input('{} Do you really want to overwrite it? '
-                    'Type "Yes" without the quotes to proceed: '.format(te.message))
+                                 'Type "Yes" without the quotes to proceed: '.format(te.message))
             if question.lower() == 'yes':
                 self.api.update_addon(
                     app_name,
@@ -733,7 +773,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.variables:
             raise InputErrorException('NoVariablesGiven')
 
@@ -765,7 +805,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.addon:
             raise InputErrorException('NoAddonGiven')
 
@@ -792,7 +832,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.addon:
             try:
                 addons = self.api.read_addons(app_name, deployment_name)
@@ -819,7 +859,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.addon:
             try:
                 addons = self.api.read_addons(app_name, deployment_name)
@@ -843,7 +883,7 @@ class AppController():
     def updateAddon(self, args):
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         try:
             self.api.update_addon(
                 app_name,
@@ -861,7 +901,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         if not args.addon:
             raise InputErrorException('NoAddonGiven')
         try:
@@ -939,7 +979,7 @@ class AppController():
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if not deployment_name:
-            raise InputErrorException('NoDeployment')
+            deployment_name = 'default'
         last_time = None
         while True:
             logEntries = []
@@ -966,11 +1006,11 @@ class AppController():
                     if args.type == 'access':
                         logEntries = filter(lambda entry:
                                             re.search(
-                                            re.compile(args.filter, re.IGNORECASE),
-                                            entry['first_request_line'] +
-                                            entry['referer'] +
-                                            entry['user_agent'] +
-                                            entry['remote_host']),
+                                                re.compile(args.filter, re.IGNORECASE),
+                                                entry['first_request_line'] +
+                                                entry['referer'] +
+                                                entry['user_agent'] +
+                                                entry['remote_host']),
                                             logEntries)
                 print_log_entries(logEntries, args.type)
             time.sleep(2)
@@ -1074,6 +1114,9 @@ class AppController():
         if not check_installed_rcs('bzr') and not check_installed_rcs('git'):
             raise InputErrorException('NeitherBazaarNorGitFound')
 
+        if args.deploy and args.ship:
+            raise InputErrorException('ShipAndDeploy')
+
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         deployment, push_deployment_name = self._get_or_create_deployment(app_name, deployment_name, args.clear_cache)
 
@@ -1085,6 +1128,11 @@ class AppController():
             print str(e)
             sys.exit(1)
 
+        if args.deploy:
+            print
+            print "Deploying newest version."
+            self.redeploy(deployment)
+
         if args.ship:
             print
             print "Deploying newest version. Press Ctrl+C to open {} in your browser.".format(deployment['name'])
